package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````H"(``#0````XL0```````#0`(``-
M`"@`'``;``8````T````-````#0```"@`0``H`$```0````$`````P```"`"
M```@`@``(`(``!,````3````!`````$````!````````````````````]!$`
M`/01```$`````!````$`````(````"`````@``!,-0``3#4```4`````$```
M`0````!@````8````&```'Q'``!\1P``!``````0```!````N*T``+B]``"X
MO0``8`(``'0"```&`````!````(```#`K0``P+T``,"]```@`0``(`$```8`
M```$````!````-0!``#4`0``U`$``$P```!,````!`````0````$````7*<`
M`%RG``!<IP``(````"`````$````!````%/E=&3X`0``^`$``/@!```H````
M*`````0````$````4.5T9'"@``!PH```<*```!P!```<`0``!`````0```!1
MY71D```````````````````````````&````$````%+E=&2XK0``N+T``+B]
M``!(`@``2`(```0````!````!````!0````#````1TY5`-_L1:9+MV53>@J.
MCJO:#P7M9!U1!````!@````%````1TY5``$``<`$`````0````(``<`$````
M`0```"]L:6(O;&0M;&EN=7@N<V\N,@``*P```$4````(````"``````0$`0E
M0`2`*`$`!:"&`(2`@0`""R@$"#B`$D&*```(10``````````````1@``````
M````````1P````````!(````20````````!*`````````$P`````````````
M`$T```!.`````````%````!1````4P````````!4````50```%8`````````
M`````````````````````%<```!8````60```%H```!;``````````````!=
M`````````%X``````````````(D'<--K&IY0H^#[29E/PYOC1\8!9J_,9D-%
MU>R[XY)\LP&+;UCH[>QOQ=\?%8PES"[%F[9K"4/6(?_D#ONA;&##Y3\L#3J7
M"\_>1RW9<5@<?ZF<F^&G`@I"^M>':W^:?#-BV^W49-1\K4OCP```````````
M``````````#5`0`````````````2````:`$`````````````$@```,\!````
M`````````!(```"D`@`````````````2````"P(`````````````$@```(L"
M`````````````!(```#T`0`````````````2````Y@$`````````````$@``
M`$<"`````````````!(````!```````````````@````8`$`````````````
M$@```'P!`````````````!(```!V```````````````2````U@(`````````
M````$@```/L!`````````````!(````N`0`````````````2````;P$`````
M````````$@```)@!`````````````!(```##`0`````````````2````$```
M````````````(````+P"`````````````!(```"I`@`````````````2````
MH@``````````````$@```"P``````````````"````";```````````````2
M````IP$`````````````$@```*D``````````````!(```"N`@``````````
M```2````Y@``````````````%@```/D``````````````!(```!:`@``````
M```````2````%`$`````````````$@```,<"`````````````!(```"Q````
M```````````2````H`$`````````````$0```.X"`````````````!(```"[
M```````````````2````T```````````````$@```*(#`````````````!(`
M``!#`0`````````````2````R`$`````````````$@```(H`````````````
M`!$```#7```````````````2````E@(`````````````$@```(0"````````
M`````!(````L`@`````````````2````]0(`````````````$@```.``````
M`````````!(```"*`0`````````````2````F@``````````````$@```"4!
M`````````````!(````7`@`````````````2````>`(`````````````$@``
M`,(``````````````!(```"(```````````````1````/`$`````````````
M$@```)(``````````````!(```!K`@`````````````1````WP(`````````
M````$0````D!`````````````!(```!2`0`````````````2````.`(`````
M````````$@```(,!`````````````!(```!5```````````````2````NP$`
M````````````$@```)$!`````````````!(```!G```````````````B````
MM@$`````````````$@```"0$```4P```!````!$`&`"&`P``T%(``!`"```2
M``X`-@0``"`^```O!```$@`.`"X$``"P0@``0@```!(`#@`L`P``8#P``#L`
M```2``X`>@,``*`\``!T`0``$@`.`/X#```8P````````!``&`#L`P``+,``
M```````0`!D`5@,``%!"``!9````$@`.`#D#````8```!````!$`$`"K`P``
MP$\``,D````2``X`XP,``)!0``!1````$@`.`!L#``#P.0``$````!(`#@"W
M`P```,`````````0`!@`%P0````Z``!7`@``$@`.``4$````10``V0```!(`
M#@#/`P``T#@``#@````2``X`N0,```#`````````(``8`/$#``#@10``K`<`
M`!(`#@#7`P``&,`````````0`!D`D`,``-!$```P````$@`.`&0#```0.0``
MV@```!(`#@#$`P``\%```-L!```2``X`8@```$`@``!6`@``$@`.`+T#``"@
M(@``+````!(`#@!``P``D$T``"4"```2``X`1@````1@```$````$0`0``!?
M7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7TE4
M35]R96=I<W1E<E1-0VQO;F5486)L90!?24]?<W1D:6Y?=7-E9`!?7VQI8F-?
M<W1A<G1?;6%I;@!?7V-X85]F:6YA;&EZ90!?7W)E9VES=&5R7V%T9F]R:P!?
M7V5N=FER;VX`<W1R;F-M<`!L<W1A=#8T`&%C8V5S<P!O<&5N9&ER`')E861D
M:7(V-`!S=')L96X`7U]S<')I;G1F7V-H:P!U;FQI;FL`8VQO<V5D:7(`<FUD
M:7(`4$Q?8W5R<F5N=%]C;VYT97AT`&)O;W1?1'EN84QO861E<@!097)L7VYE
M=UA3`%!E<FQ?;F5W6%-?9FQA9W,`<F5A9&QI;FL`4&5R;%]S=E]S971P=@!M
M96UC:'(`4&5R;%]S=E]S971P=FX`7U]M96UM;W9E7V-H:P!R96%L;&]C`&=E
M='!I9`!?7VUE;6-P>5]C:&L`<W1R8VAR`'-T<F1U<`!S=')T;VL`<W1R8VUP
M`'-T<G)C:'(`<W1D97)R`%]?=F9P<FEN=&9?8VAK`&5X:70`;'-E96LV-`!R
M96%D`&=E='5I9`!M:V1I<@!?7V5R<FYO7VQO8V%T:6]N`%]?9G!R:6YT9E]C
M:&L`;W!E;C8T`%!E<FQ?9W9?9F5T8VAP=@!097)L7V=E=%]S=@!097)L7V-R
M;V%K7VYO8V]N=&5X=`!097)L7VUG7W-E=`!097)L7W-Y<U]I;FET,P!097)L
M7V%T9F]R:U]U;FQO8VL`4&5R;%]A=&9O<FM?;&]C:P!03%]D;U]U;F1U;7``
M4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?<&%R<V4`<&5R;%]D97-T<G5C=`!P
M97)L7V9R964`4&5R;%]S>7-?=&5R;0!P97)L7V%L;&]C`'!E<FQ?8V]N<W1R
M=6-T`'!E<FQ?<G5N`%!,7VUE;6]R>5]W<F%P`&UE;6-P>0!?7W-T86-K7V-H
M:U]F86EL`&QI8G!E<FPN<V\`;&EB8RYS;RXV`'!A<E]C=7)R96YT7V5X96,`
M<&%R7V)A<V5N86UE`%]F<%]H=P!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R
M7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`
M<VAA7V9I;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A
M;G5P`%]?9&%T85]S=&%R=`!S:&%?=7!D871E`'AS7VEN:70`7U]B<W-?<W1A
M<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S971U
M<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7V1I90!P87)?
M:6YI=%]E;G8`1TQ)0D-?04))7T147U)%3%(`1TQ)0D-?,BXQ+C,`1TQ)0D-?
M,BXS-`!'3$E"0U\R+C0`1TQ)0D-?,BXR`$=,24)#7S(N,S,`1TQ)0D-?,BXS
M+C(`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXQ`$=,24)#7S(N,``O=7-R+VQI8B]P
M97)L-2\U+C0P+V-O<F5?<&5R;"]#3U)%`````@`"``(``0`!``$``P`$``$`
M`0`"``(`!0`!``$``0`$``(``@`!``$``@`"``$`!@`$``(``0`!``$``0`!
M``$`!P`"``(``@`"``(``0`"``(``@`!``(``0`(``(``@`&``(``0`!``0`
M`@`"``(``0`!``$`!``!``(`"0`#``(`"@`"``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!`````0`*`!$#
M```0`````````$(._0````L`0P0``!````!S'VD)```*`%4$```0````M)&6
M!@``"0!A!```$````!1I:0T```@`;`0``!`````2:6D-```'`'8$```0````
MLY&6!@``!@"`!```$````'(9:0D```4`BP0``!````!T&6D)```$`)<$```0
M````$6EI#0```P"C!```$````!!I:0T```(`K00```````#PO@``!@$``/2^
M```&`@``^+X```8#``#\O@``!@0```"_```&!0``!+\```8&```(OP``!@<`
M``R_```&"```$+\```8)```4OP``!@H``!B_```&"P``'+\```8,```DOP``
M!@T``"B_```&#@``++\```8/```POP``!A```#2_```&$0``.+\```82```\
MOP``!A,``$"_```&%```1+\```85``!(OP``!A8``$R_```&%P``4+\```88
M``!4OP``!AD``%B_```&&@``7+\```8;``!@OP``!AP``&2_```.'0``:+\`
M``8>``!LOP``!A\``'"_```&(```=+\```8A``!XOP``!B(``'R_```&(P``
M@+\```8D``"$OP``!B4``(B_```&)@``C+\```8G``"0OP``!B@``)2_```&
M*0``F+\```8J``"<OP``!BL``*"_```&+```I+\```8M``"HOP``!BX``*R_
M```&+P``L+\```8P``"TOP``!C$``+B_```&,@``O+\```8S``#`OP``!C0`
M`,2_```&-0``R+\```8V``#,OP``!C@``-"_```&.0``U+\```8Z``#8OP``
M!CL``-R_```&/```X+\```8]``#DOP``!CX``.B_```&/P``[+\```9!``#P
MOP``!D(``/2_```&0P``^+\```9$``#LO@``!T```+B]```#````(+\``/R_
M``!%````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!3@^P(Z,<"``"!P]>>``"+@S0```"%P'0"_]"#Q`A;P_^S!````/^C"```
M``````#_HPP```!H`````.G@____C4PD!(/D\/]Q_%6)Y5>)SU93Z'D"``"!
MPXF>``!1@^PLBT$$B474BT$(B4709:$4````B47DC4704(U%U%!1_Y,$`0``
MBX,P````@\0,4%#_LXP```!GZ%0T``"+@_0```"#Q!"`.``/A"<!``"+@X0`
M``!EBP"`B*("```#BP>-<`.#P`2)=<P]____/P^'AP$``(/L#,'@`E#_D^0`
M``"+==2+/XG!B8-(`0``BP:#Q!")`8V#"Z/__XE!!(V#-`$``(L`B4$(C8,.
MH___B4$,@_\!#XYA`0``B4W(C48$C5$0C32^+HVT)@````"0BPB#P`2#P@2)
M2OPYQG7QBTW(@\<#@^P,C8,P=O__QP2Y`````&H`4?]US%#_LT`!``#_DR0`
M``"#Q""%P`^$F````(/L#/^S0`$``(U]X/^3P````(GZB<:-@\>A___H;!``
M`(/$$(7`#X2#````@^P,_[-``0``_Y,<````@\00_Y.`````BT7D92L%%```
M``^%R@```(UE\(GP65M>7UV-8?S#_Y-D````B8-``0``A<`/A)T```"#[`Q0
M_Y.4````BX.$````98L0@\00QH(Z!0```.FI_O__@^P,_[-``0``_Y-(````
M@\00Z5'___^+@T0!``"%P'02@^P,4&?HBBT``(/$$.EA____B?J-@WRA___H
MM0\``(F#1`$``(7`#X1&____Z]&+1>1E*P44````=2I04(V#=Z'___^S^```
M`%#_D^````"_!````.F__O__@^P,:@'_DQ@!``#HBC(``&:09I!FD&:09I`Q
M[5Z)X8/D\%!44N@8````@<,PG```:@!J`%%6_[,<`0``Z&G]___TBQPDPV:0
M9I"+'"3#9I!FD&:09I!FD&:0Z.````"!PON;``"-BC@!``"-@C@!```YR'0=
MBX)@````A<!T$U6)Y8/L%%'_T(/$$,G#+HUT)@##C;0F`````.B@````@<*[
MFP``58GE4XV*.`$``(V".`$``(/L!"G(B</!Z!_!^P(!V-'X=!2+DG````"%
MTG0*@^P(4%'_TH/$$(M=_,G#+HVT)@````"058GE4^A7____@<-GFP``@^P$
M@+LX`0```'4HBX,4`0``A<!T$H/L#/^S)`$``/^3%`$``(/$$.@T____QH,X
M`0```8M=_,G#+HVT)@````#I6____XL4),-FD&:09I!FD&:09I!FD&:09I!F
MD&:09I!FD&:09I!FD&:09I!FD&:09I!FD&:09I!FD&:09I"058GE5U:-C:3^
M__]3B<.!['P!``")A8C^__]EH10```")1>0QP.L9+HVT)@`````NC;0F````
M`"Z-M"8`````D(M4@QP/RHD4@8/``8/X$'7OBXVH_O__B[78_O__C96L_O__
MB[W<_O__BX7@_O__B8V4_O__C4VLBYVD_O__B8V,_O__ZT#K."Z-M"8`````
M+HVT)@`````NC;0F`````"Z-M"8`````+HVT)@`````NC;0F`````"Z-M"8`
M````B8V4_O__B860_O__BPJ#P@2+0A0QR#'PB?Z+O9#^__\QV(N=E/[__]'`
MB4(T.96,_O__=<N+O8C^__^+1PR+#XM?$(MW!(F%E/[__XN%I/[__XFUC/[_
M_XMW"(V4`YEY@EJ)R(N]E/[__XF=>/[__\'`!8GS`<*)\(NUC/[__XF=A/[_
M_S'X(?#!S@(Q^(G/`<*)V(F]?/[__S'P(<B+C:C^__\QV(N=E/[__XV,"YEY
M@EJ+G83^__\!R(G1P<$%`<B)^<')`HG/B?&)O9#^__\Q^8N]K/[__R'1P<H"
M,?&-O#N9>8):`?F)Q\''!8T<.8N]D/[__XF=@/[__XGY,=$AP<'(`C'YB[VP
M_O__C;0^F7F"6@'QB=[!Q@6-/#&)T8NUM/[__S'!(=F+G9#^__\QT8V<,YEY
M@EJ)_@'9P<8%C30QB;60_O__B[6`_O__P<X"B?&)QC'.B?.+M;C^__\A^\'/
M`HV4,IEY@EJ+M9#^__\QPP':BYV0_O__P<8%C30RB<HQ^B':BYV\_O__,<J-
MA!B9>8):`=")\L'"!0'"BX60_O__B96`_O__B?J+G<#^___!R`(QPHV,&9EY
M@EHA\L'.`C'Z`<J+C8#^___!P06-'`J+C8#^__^)PC'R(<J+C<3^__\QPHV,
M#YEY@EJ+O<C^__\!RHG9P<$%C80XF7F"6@'*B?&)E9#^__^+E8#^___!R@(Q
MT2'9P<L",?$!R(N-D/[__\'!!8T\"(N-D/[__XG0,=@AR(N-S/[__S'0C8P.
MF7F"6@'(B?G!P06--`B+A9#^__^)V8FU@/[__XNUT/[__\'(`C'!C90RF7F"
M6HNU@/[__R'YP<\",=G!Q@4!RHN-@/[__XTT,HG",?HARHN-U/[__S'"C8P+
MF7F"6HN=V/[__P'*B?'!P06-A!B9>8):`<J)^8F5D/[__XN5@/[__\'*`C'1
M(?'!S@(Q^0'(BXV0_O__P<$%C1P(BXV0_O__B=`Q\"'(BXW<_O__,="-C`^9
M>8):B[W@_O__`<B)V<'!!8V4.IEY@EH!R(GQB86`_O__BX60_O__P<@",<$A
MV<'+`C'Q`<J+C8#^___!P06-/`J+C8#^__^)PC':(<J+C>3^__\QPHV,#IEY
M@EH!RHGYP<$%C30*BY6`_O__B=F)M9#^__^+M>C^___!R@(QT8V$,)EY@EHA
M^<'/`C'9`<B+C9#^___!P06--`B+C9#^__^)T#'X(<B+C>S^__\QT(V,"YEY
M@EJ+G?#^__\!R(GQP<$%C90:F7F"6@'(BXV0_O__P<D"B8V0_O__,?DA\3'Y
M`=&)PL'"!0'1B?+!R@*)TXN5]/[__XVT%Z'KV6Z+O9#^__^)^C':,<+!R`(!
M\HG.P<8%`?*+M?C^__^-O#>AZ]ENB=XQQC'.P<D"`?Z)U\''!0'^B<^+C?S^
M__^-G`NAZ]ENB<$Q^3'1P<H"`=F)\\'#!0'9B=.+E0#___^-E!"AZ]ENB?@Q
MV#'PP<X"`=")RL'"!0'0BY4$____C;P7H>O9;HG:,?(QRL')`@'ZB<?!QP4!
M^HN]"/___XV\.Z'KV6Z)\S'+,<,!^XG7P<@"P<<%`?N)QXN%#/___XVT!J'K
MV6Z)R#'X,=#!R@(!\(G>P<8%`?")UHN5$/___XV4$:'KV6Z)^3'Q,=G!RP(!
MT8G"P<(%`=&+E13___^-O!>AZ]ENB?(QVC'"P<@"`?J)S\''!0'ZB<>+A1C_
M__^-A`:AZ]ENB=XQ_C'.P<D"`<:)T,'`!0'&BX4<____C9P#H>O9;HGX,<@Q
MT`'8B?/!PP4!V,'*`HG3BY4@____C907H>O9;HG/,=\Q]\'.`@'7B<+!P@4!
MUXN5)/___XV,$:'KV6Z)VC'R,<+!R`(!RHGYP<$%`<J)P8N%*/___XV$`Z'K
MV6Z)\S'+,?O!SP(!PXG0P<`%`<.+A2S___^-M`:AZ]ENB<@Q^#'0P<H"`?")
MWL'&!0'PB=:+E3#___^-E!&AZ]ENB?DQ\3'9P<L"`=&)PL'"!0'1BY4T____
MC;P7H>O9;HGR,=HQPL'(`@'ZB<_!QP4!^HG'BX4X____C80&H>O9;HG>,?XQ
MSL')`@'&B=#!P`4!QHN%//___XV<`Z'KV6Z)^#'(,=#!R@(!V(GSP<,%`=B+
MG4#___^-O!^AZ]ENB<LQTS'SP<X"`?N)Q\''!0'[B=>)G9#^__\)]XG3(<<A
M\\'(`@G[B[U$____C8PYW+P;CP'9BYV0_O__P<,%C3P9B?$)P8G+BXV0_O__
M(<N)\2'!"=F+G4C___^-E!K<O!N/`<J)^<'!!0'*B<&)E8#^__^+E9#^___!
MR@()T8G+B<$A^R'1"=F+G4S___^-G![<O!N/B[6`_O__`=F+G8#^___!Q@6-
M-#&)^8G7B;60_O__P<D"B=8ASPG.(=Z)^PGSB[50____C80PW+P;CXNUD/[_
M_P'8BYV0_O__P<8%C3PPBX6`_O__B<[!R`()QB'>B<LAPPGSB[54____C90R
MW+P;CXG^`=K!Q@6)PXTT,HN5D/[__XFU@/[__XG&P<H""=8ATR'^"?.+M5C_
M__^-C#'<O!N/B[6`_O__`=F+G8#^___!Q@6--#&)^8G7B;60_O__P<D"B=8A
MSPG.(=Z)^PGSB[5<____C80PW+P;CXNUD/[__P'8BYV0_O__P<8%C3PPBX6`
M_O__B<[!R`()QB'>B<LAPPGSB[5@____C90RW+P;CXG^`=K!Q@6)PXTT,HN5
MD/[__XFU@/[__XG&P<H""=8ATR'^"?.+M63___^-C#'<O!N/B[6`_O__`=F+
MG8#^___!Q@6--#&)^8G7P<D"B;60_O__B=8ASPG.(=Z)^PGSB[5H____C80P
MW+P;CXNUD/[__P'8BYV0_O__P<8%C3PPBX6`_O__B<[!R`()QB'>B<LAPPGS
MB[5L____C90RW+P;CXG^`=K!Q@6)PXTT,HFU@/[__XN5D/[__XG&P<H""=8A
MTR'^"?.+M7#___^-C#'<O!N/B[6`_O__`=F+G8#^___!Q@6--#&)^8G7B;60
M_O__P<D"B=8ASPG.(=Z)^PGSB[5T____C80PW+P;CXNUD/[__P'8BYV0_O__
MP<8%C3PPBX6`_O__B<[!R`()QB'>B<LAPPGSB[5X____C90RW+P;CXG^`=K!
MQ@6)PXTT,HN5D/[__XFU@/[__XG&P<H""=8ATR'^"?.+M7S___^-C#'<O!N/
MB[6`_O__`=F+G8#^___!Q@6--#&)^8G7B;60_O__P<D"B=8ASPG.(=Z)^PGS
MBW6`C80PW+P;CXNUD/[__P'8BYV0_O__P<8%C3PPBX6`_O__B<[!R`()QB'>
MB<LAPPGSBW6$C90RW+P;CXG^`=K!Q@6)PXTT,HN5D/[__XFU@/[__XG&P<H"
M"=8ATR'^"?.+=8B-C#'<O!N/B[6`_O__`=F)T\'&!8TT,8GYB[V`_O__P<D"
MB;60_O__B=8)SB'+(?X)\XMUC(V$,-R\&X^+M9#^__\!V,'&!0'PB?Z)S\'.
M`HGS"?>+M9#^__\A]XG.(=X)_HM]D(V4.MR\&X\!UHG"P<(%`=:+E9#^___!
MR@*)UXM5E(V4$=;!8LJ)V3'Y,<'!R`(!T8GRP<(%`=&+59B-G!/6P6+*B?HQ
MPC'RP<X"`=J)R\'#!0':BUV<C;P?UL%BRHG#,?,QR\')`@'[B=?!QP4!^XM]
MH(V\.-;!8LJ)\#'(,=#!R@(!^(G?P<<%`?B)UXM5I(V4%M;!8LJ)SC'^,=[!
MRP(!UHG"P<(%`=:+5:B-C!'6P6+*B?HQVC'"P<@"`<J)\<'!!0'*B<&+1:R-
MA`?6P6+*B=\QSS'WP<X"`<>)T,'`!0''BT6PC9P#UL%BRHG(,?`QT,'*`@'8
MB?O!PP4!V(G3BU6TC901UL%BRHGQ,=DQ^<'/`@'1B<+!P@4!T8M5N(VT%M;!
M8LJ)VC'Z,<(!\HG.P<8%P<@"`?*)QHM%O(V$`];!8LJ)^S'S,<O!R0(!PXG0
MP<`%`<.+1<"-O`?6P6+*B?`QR#'0P<H"`?B)W\''!0'XB=>+5<2-E!;6P6+*
MB<XQ_C'>P<L"`=:)PL'"!0'6BU7(C8P1UL%BRHGZ,=HQPL'(`@'*B?'!P04!
MRHG!BT7,C80'UL%BRHG?,<\Q]P''B=#!P`4!QXM%T,'.`HV<`];!8LJ)R#'P
M,=#!R@(!V(G[P<,%`=B)TXM5U(V4$=;!8LJ)\3'9,?G!SP(!T8G"P<(%`=&+
M5=B-M!;6P6+*B=HQ^C'"P<@"`?*)SL'&!0'RBW7<C;0SUL%BRHG[,<,QR\')
M`@'SB=:)C9#^__^+C7S^___!Q@4!\XMUX(VT,=;!8LJ)P0'WB[60_O__,?&)
MSHG9,=;!P04!_HN]B/[__P'.B3>+M8S^__\!\\'*`HE?!(N=A/[__P':BYV4
M_O__B5<(BY60_O__`=J)5PR+G7C^__\!V(E'$(M%Y&4K!10```!U"X'$?`$`
M`%M>7UW#Z"DC```NC;0F`````)!5B<&)Y5?HW2(``(''U8P``%93@^P<B57<
MBX>X````B7WDBP"%P`^$DP````^V$832=`6`^CUU4#'_BQB%VW0ZB4W@B<:)
M1=B)V(GSB<9FD(/L!%?_=>!6BT7D_Y#P````@\00A<!U!H`\/CUT,HMS!(/#
M!(7V==B)\XUE](G86UY?7<.-="8`B<H/MEH!@\(!A-MT!8#[/77P*<J)U^N:
MBT78B?&)WHU<.0$IQHM%W,'^`HDPC67TB=A;7E]=PS';Z[<NC;0F`````"Z-
M="8`58GE5N@+(@``@<8'C```4X/L>&6+'10```")7?2)PXU%E%!3_Y;8````
M@\00A<!U-XM5I('B`/```('Z`$```'0(@?H`H```=2"#[`AJ`E/_EFP```"#
MQ!"%P`^4P`^VP.L'+HUT)@`QP(M5]&4K%10```!U!XUE^%M>7</HSB$``"Z-
MM"8`````C;8`````58GE5U;H>B$``('&=HL``%.![(P```!EBQT4````B5WD
MB<.%VW0%@#L`=1R+1>1E*P44````#X5A`0``C67T6UY?7<.-="8`@^P,4_^6
M?````(G'@\00A<!TT8/L#%?_EI@```"#Q!"%P`^$X````(!X$RZ-4!-U!X!Z
M`0!TW)"`>!,N#X3F````@^P,B95P____4_^6I````(N5</___XF%=/___XD4
M)(F5;/____^6I````(N-=/___XU,`0*)#"2)C7#_____EL0```")A73___]8
MC88HH?__6HN5;/___U)34(N-</___U%J`O^U=/____^6Z````(U%A(/$&%#_
MM73_____EG0```"#Q!"#^/]T#XM%E"4`\```/0!```!T;(/L#/^U=/____^6
MJ````(/$$(/L#/^U=/____^6:````(/$$.D.____C78`@^P,5_^6O````(D<
M)/^6T````(/$$.G!_O__+HUT)@"`>@$N#X40____@'H"``^$U_[__^D!____
MC;0F`````(N%=/___^AE_O__ZYGH'B```"Z-M"8`````C;8`````58GE5E/H
MMNW__X'#QHD``(NSA````(V#A.'__U"-@RZA____LX@```!09?\V_Y/\````
M6(V#Z*+__UIJ`%!0C8-*H?___[-`````4&7_-O^3D````(/$((UE^%M>7<.0
M58GE5U93@>P`$```@PPD`(/L,.A<'P``@<98B0``B974[___B<.-O>3O__]E
MH10```")1>0QP(V&7Z'__VC_#P``5U#_EMP```"#Q!"%P'X3B<*-0/^`O!7C
M[___`'5`A<!U,(N&A````(/L!/^UU.___U-E_S#_EE````"#Q!"+1>1E*P44
M````=4N-9?1;7E]=PXG"+HVT)@````!FD(/L!%*)E=#O__]J+U?_ENP```"#
MQ!"%P'2JBY70[___BX:$````4E=39?\P_Y:P````@\00ZZGHU!X``(UT)@!5
MB>57B<<QP%;HAAX``('&@H@``%.#[$B`.CT/E,")==1EBQT4````B5WDB=,!
MPU/_EJ0```"-5>"#Q!")1<R)^.AJ^___A<`/A#(!``"#[`R)QE"+3=3_D:0`
M``"+5<R#Q!`YT`^#]0```(M%X(MUU,'@`HE%R(N&N````(E%T`^V!X3`#X3-
M`0``/#T/A,4!``")^"Z-M"8`````C78`#[90`8/``832=`6`^CUU\"GXBU7,
MBTW0@^P,BW7(C400`@,Q4(M%U/^0Q````(D&@\00A<!T:(M-T(MUR(L!C4\!
MBQ0P#[8'B`(\/70UA,!U(NLOZQHNC;0F`````"Z-M"8`````+HVT)@````!F
MD#P]=`\/M@&#P@&#P0&(`H3`=>W&`CTQP"Z-M"8`````#[8,`XA,`@&#P`&$
MR77QBT7D92L%%`````^%'@$``(UE]%M>7UW#+HVT)@````"0,<`NC;0F````
M`(VV``````^V%`.(%`:#P`&$TG7RZ[^+1=2+@+@```"+$(E%T(LRA?8/A,<`
M```Q]HVV`````(GP@\8!BPRRA<EU](T$A0P```")1<2+1=2+B#P!``"%R75E
MBT74@^P,B57`QX`\`0```0```/]UQ/^0Q````(/$$(7`#X15____C12U````
M`(E5R/]UQ%*+5<!24(E%Q(M%U/^0``$``(M%T(M-Q(/$$(D(QT2Q!`````")
M=>#I7/[__XUT)@"#[`C_=<12_Y`X````B<&+1="#Q!")"(7)#X3X_O__C02U
M`````(E%R.O!+HUT)@`QP.E3_O__QT7$"````#'VZ4G____H7AP``"Z-M"8`
M````C;8`````Z$(<```%"X8``%6)Y8/L"(V0A.'__U*-D"ZA____L(@```!2
MBY"$````9?\R_Y#\````@\00R<,NC;0F`````%6)Y5=64X'L`!```(,,)`"!
M[``0``"##"0`@^PLZ)[I__^!PZZ%``!EH10```")1>0QP(VUX^___XV]XM__
M__^3%````(/L"(V3:J'__U)0C8-NH?__4&@!$```:@)6_Y/H````@\0<:``0
M``!75O^3W````#'2@\00A<!X08/L#(U(`8G&48F-U-____^3Q````(G"@\00
MA<!T(XN-U-___U%65U")A=3?____DU0```"+E=3?__^#Q!#&!#(`BT7D92L%
M%````'4*C67TB=!;7E]=P^@V&P``C;8`````Z"(;```%ZX0``.D1____D%6)
MY5=64X'L`!```(,,)`"![)P```#HM>C__X'#Q80``(M%"(F%=.___XV-A.__
M_XG*C8-\H?__98L]%````(E]Y(M]#(F-:.___^BP]___@^P(:B^)QO^U=.__
M__^3/````(/$$(7`=#:+M73O__^-@X6A__^)\NC3^___B?"+5>1E*Q44````
M#X7#`0``C67T6UY?7<,NC;0F`````)"#[`Q7_Y,(`0``6EF-BY*A__^)C7#O
M__]14/^3U````(V+E*'__XG'C8.=HO__@\00B85D[___A?]TCX`_`(F-8.__
M_P^$"P$``(VV`````(7V=!:#[`A75O^3$`$``(/$$(7`#X3$````@^P,5_^3
MI````(G"C40'_X/$$#G'<AGK*RZ-M"8`````+HUT)@#&``"#Z`$YQW0%@#@O
M=/&#[`Q7_Y.D````B<*#Q!")E6SO__^#[`S_M73O____DZ0```"+E6SO__^-
M1`(!@\00/?\/```/A^_^__^#[`3_M73O____M6#O__]7C;WD[____[5D[___
M:``0``!J`E?_D^@```"#Q!C_M6CO__]7_Y-T````@\00A<!U$HN%E.___R4`
M\```/0"```!T4H/L"/^U<.___VH`_Y/4````B<>#Q!"%P`^$?O[__X`_``^%
M^_[__X7V=`6`/BYT$KH!````C;MZH?__Z4#___]FD(!^`0!TN.OF+HVT)@``
M``"#[`AJ`5?_DVP```"#Q!"%P'6;B?J-@X6A___H$/K__X/L#%?_DP@!``"#
MQ!#I+?[__^C)&```+HVT)@````"058GE5NA[&```@<9W@@``4XM="(/L"&HO
M4_^66````(U0`8/$$(7`B?`/1=J)70B-9?A;7EW_H`@!```NC70F`%6)Y5=6
M4X'L`!```(,,)`"#["SH#>?__X'"*((``&6+-10```")=>2+=0B%]@^$O0``
M`(`^``^$M````(/L#%:)E=3O____DJ0```"->`&#Q!"!_P`0```/A^(```"#
M_P2+E=3O__^-G>3O__\/@Z4```"%_P^%S0```(U$`_\YPW(7ZQHNC;0F````
M`(UV`,8``(/H`3G8=`6`."]T\8/L"&HO4XF5U.____^26````(N5U.___X/$
M$(7`=#(YPW)V@^P,4_^2"`$``(/$$(M5Y&4K%10````/A9````"-9?1;7E]=
MPRZ-M"8`````D(M%Y&4K!10```!U<XV">J'__XE%"(UE]%M>7UW_H@@!``"-
MM@````"+3#[\B8P]X.___XG!B=_!Z0+SI>E*____C;0F`````,8``.N%C78`
M,<#KBXUT)@`/M@Z(C>3O___WQP(````/A![___\/MTP^_F:)C#WB[___Z0S_
M___H#!<``"Z-M"8`````C70F`.B[%@``@<&[@```58GE5U93C;&6H?__@^P\
MB4W4B[FX````98L=%````(E=Y(U=X(G:B?#HI_/__X7`="R+5>"+!XT$D(M0
M!(D0A=)TXF:0BU`(@\`$B1"%TG7TB=J)\.A[\___A<!UU(M%U(NXN````(VP
MGZ'__XG:B?#H7_/__X7`=#2+5>"+!XT$D(M0!(D0A=)TXBZ-M"8`````9I"+
M4`B#P`2)$(72=?2)VHGPZ"OS__^%P'7,BT74B[BX````C;"GH?__B=J)\.@/
M\___A<!T-(M5X(L'C020BU`$B1"%TG3B+HVT)@````!FD(M0"(/`!(D0A=)U
M](G:B?#HV_+__X7`=<R+1=2+N+@```"-L+"A__^)VHGPZ+_R__^%P'0TBU7@
MBP>-!)"+4`2)$(72=.(NC;0F`````&:0BU`(@\`$B1"%TG7TB=J)\.B+\O__
MA<!US(M%U(V(MZ'__XNPN````(E-T(M%T(G:Z&OR__^%P'0QBU7@BP:-!)"+
M4`2)$(72=.&-M@````"+4`B#P`2)$(72=?2+1=")VN@Z\O__A<!USXM%U(NX
MN````(VPQZ'__XG:B?#H'O+__X7`=#.+5>"+!XT$D(M0!(D0A=)TXBZ-M"8`
M````D(M0"(/`!(D0A=)U](G:B?#HZ_'__X7`=<V+1=2-B'RA__^+L+@```")
M3<R+1<R)VNC+\?__A<!T,8M5X(L&C020BU`$B1"%TG3AC;8`````BU`(@\`$
MB1"%TG7TBT7,B=KHFO'__X7`=<^+1=2-B-.A__^+L+@```")3<2+1<2)VNAZ
M\?__A<!T,(M5X(L&C020BU`$B1"%TG3A+HUT)@"+4`B#P`2)$(72=?2+1<2)
MVNA*\?__A<!UT(M%U(V(W:'__XNPN````(E-R(M%R(G:Z"KQ__^%P'0PBU7@
MBP:-!)"+4`2)$(72=.$NC70F`(M0"(/`!(D0A=)U](M%R(G:Z/KP__^%P'70
MBT74B[BX````C;#GH?__B=J)\.C>\/__A<!T,XM5X(L'C020BU`$B1"%TG3B
M+HVT)@````"0BU`(@\`$B1"%TG7TB=J)\.BK\/__A<!US8M%U(NXN````(VP
MA:'__XG:B?#HC_#__X7`=#2+5>"+!XT$D(M0!(D0A=)TXBZ-M"8`````9I"+
M4`B#P`2)$(72=?2)VHGPZ%OP__^%P'7,BT74B=J-@/&A___H1_#__X7`=`J)
MPHM%R.B)]/__BWW4B=J-AP*B___H*?#__X7`=`V)PHV'%*+__^AH]/__BT74
MB=J-@!^B___H"/#__XG"A<!T+(M%S.A*]/__BT7D92L%%````'4XBT74C9!`
MHO__BT70@\0\6UY?7>DF]/__BT74B=J-@"^B___HQN___X7`=,B)PHM%Q.@(
M]/__Z[SHT1(``)#HPA(```6+?```58GE@^P898L5%````(E5](U5\(V`TZ'_
M_^B([___A<!T)`^V$(#Z,`^4P(32#Y3""="#\`$/ML"+5?1E*Q44````=0;)
MPS'`Z^[H=Q(``(VT)@````!5B>53Z!?@__^!PR=\``"#[!1EH10```")1?2-
M10Q0B47PBX.<````_W4(:@+_,/^3>````,<$)/\```#_DQ@!```NC;0F````
M`(VV`````%6)Y5=64XV<)```__^![``0``"##"0`.=QU\H/L+.BMW___@<.]
M>P``B874__[_B<9EH10```")1>0QP&H":@!J`%;_DPP!``"-C=S__O^#P/^#
MTO^)A<C__O^+M<C__O^)UXF5S/_^_\'_'S'X*?@QTB7__P``,?HQ^"GX&?J+
MO<S__O\IQAG7@\00A?\/B/0````NC;0F`````(UT)@")C<C__O]J`%=6_[74
M__[__Y,,`0``BXW(__[_(="#Q!"#^/\/A.,```"#[`1H"``!`%&)C<C__O__
MM=3__O__DUP```"+C<C__O^#Q!"#^/\/A)H```"#^`=V<(U$`?@YR')HB;7(
M__[_C14H`0``B;W,__[_ZP\NC;0F`````(/H`3G(<CF+/!HY.'7RB[,L`0``
M.7`$=>>+M<C__O\IR(N]S/_^_YD!\!'ZBTWD92L-%````'5QC67T6UY?7<.+
MM<C__O^+O<S__O^!Q@``__^#U_^)\(GZ-0``___WT@G0#X48____N/____^)
MPNN[BT7D92L%%````'4L@^P,C8-/HO__4&?H`_[__XM%Y&4K!10```!U$(/L
M#(V#0J+__U!GZ.?]___H4A```&:058GE4^CWW?__@<,'>@``@^P$_Y.T````
M@^P,4/^3K````(/$$(7`=`*+`(M=_,G#58GE5^C?#P``@<?7>0``5E.#["R+
M10B)1=2-MUNB__^)\&6+%10```")5>2-5>#HS.S__X7`=`>`.`")PW4ABT7D
M92L%%`````^%A0```(M5U(UE](GP6UY?7>GP\/__@^P,_W74_Y>D````B470
MB1PD_Y>D````BU70C50"`HD4)(E5T/^7Q````(/$#(G!C8>2H?__4U"-AYVB
M____==10BU704FH"48E-U/^7Z````(M-U(/$((M%Y&4K!10```!U$(UE](GP
MB<I;7E]=Z7SP___H1P\``(VT)@````!5B>57Z/\.``"!Q_=X``!64X'L#`$`
M`(M%"(F%!/___V6A%````(E%Y(V'<J+__\=%G`````#'1;0`````QT60````
M`(E%E(V'>J'__XE%F(V'#:+__XE%I(V'=Z+__XE%J(V'*J+__XE%K(V'?Z+_
M_XE%L(V'@Z+__XE%B(V'B*+__XE%C(V%(/___XF%%/___XG"C8=\H?__B84`
M____Z'OK__^%P'0+@#@`B<,/A1P%``#_E[0```"#[`Q0_Y>L````@\00A<`/
MA%$$``"+,(7V#X1'!```@^P,5O^7I````(U<``&#Q!"#[`Q3_Y?$````B<(/
MM@:#Q!")G0S___^)E?C^__^$P'1FC8^1HO__B8T(____B?&)UHG*9I"#[`P/
MML")E1#___]0_[4(____4VH"5O^7Z````(N%#/___XN5$/___XG!@\(!.=@/
M0LN)R"G8@\`".<@/0L$IRX/&`H/$((U<`_X/M@*$P'6NC5V@C8<4HO__ZPV-
M=@"+0P2#PP2%P'0VBY44____Z(OJ__^)QH7`=.6`.`!TX.A+Z___A<!TUX/L
M#%;_EP@!``")PX/$$(7`=2^-="8`C764BQZ%VW0B@#L`#X0^`P``B=CH%^O_
M_X7`#X7_````BUX$@\8$A=MUWH/L#%/_EZ0```!:_[7X_O__B<;_EZ0```"-
MM`8$!```B;4,____B30D_Y?$````B840____B<*-AY:B____M?C^__]0C8>4
MH?__B84(____4(V'FZ+__U-05HG6:@)2_Y?H````@\0H:,`!``!6_Y<8````
M@\00@_C_=1'_EQ````"+`(/X$0^%,P,``(/L"/^U%/____^U$/____^7V```
M`(G#@\00A<!T:H/L#/^U$/___XN%!/____\PC8=0H___4#'VBX><````:@+_
M,/^7+````(/$((M%Y&4K!10````/A;@$``"-9?2)\%M>7UW#C78`@^P,@\8$
M4_^7"`$``(G#@\00A<`/A,G^___I[/[__Y"+A3#___\E`/```#T`0```=82+
MM3C_____E[0````YQ@^%</___XN%,/___R7_`0``/<`!```/A5K___^#[`S_
MM0S_____E\0```"+E13___^)QHV'9J+__^C"Z/__@\00A<`/A)<"``"#[`A0
MBX4$_____S!GZ*7P__^)A?C^__^#Q!"%P`^$=`(``(/L#/^U^/[___^7I```
M`(G"@\00@_@#=DN#[`B-AZ2B__]0BX7X_O__B97T_O__C400_%#_EQ`!``"#
MQ!"%P'4CBY7T_O__@_H$#X1*`P``BX7X_O__@'P0^R\/A#D#``"-=@"+E13_
M__^-A].A__^)A13____H&>C__X7`#X0)`@``#[8`A,`/A/X!```\,`^$]@$`
M`(N%%/___XV70*+__^@][/___Y<4````C9?HHO__B944____4E"-A\BB____
MM0C_____M1#___]0_[4,____:@)6_Y?H````C8?6HO__@\0@B84$____ZTF-
MM@````#_EQ````"#.!%U3_^7%````(/#`8/L#/^U%/___U-0_[4(_____[40
M_____[4$_____[4,____:@)6_Y?H````@\0P@^P(:,`!``!6_Y<8````@\00
M@_C_=*:#[`S_M1#_____EV@```"+A0#___^)\NAZZ___B30D9^@A^O__@\00
MZ;S]__\NC;0F`````)`QV^G4_/__+HVT)@````"0C5V(+HVT)@`````NC70F
M`(L#A<!T'HN5%/___^C?YO__A<!T!8`X`'5&BT,$@\,$A<!UXH/L#(VW:Z+_
M_[L-````:@W_E\0```")PH/$$(F%^/[__[A3````QX4,____#0```.F#^___
MC;0F`````(/L#(/#!%#_EP@!``"#Q!"%P'2,B<;I+OO__X/L"%#_M1#___^+
MA03_____,(V'%*/__^GE_/__+HVT)@````"#[`Q09^A&^?__@\00BT7D92L%
M%`````^%G@$``(E="(UE](GX6UY?7?^@"`$``)"+A03___^+`(F%^/[__^EY
M_?__+HUT)@"#[`AJ`/^U^/[___^7*````(/$$(7`#X3N_?__B84$____Z.'V
M__^)A?C^__^)E?S^__^%T@^(S_W__X/`]FH`@]+_4E"+C03___]1_Y<,`0``
MC46"@\0,:@90BXT$____4?^77````(N-!/___X/$$(/X!@^%_@```(%]@@!#
M04,/A8/]__]F@7V&2$4/A7?]__]J`(N%^/[__XU=NXN5_/[__X/`SH/2_U)0
M48F-%/____^7#`$``(/$#&HH4XN-%/___U'_EUP```"#Q!"#^"@/A:````"-
MA^BB___&1>,`4(V'N:+__U/_M0C_____M1#___]0_[4,____:@)6_Y?H````
M@\0@Z;3]__^+A03___^+2`2%R0^$N?S__X/L#%&)C03_____EZ0```"#Q!"#
M^`,/AIW\__^#[`B-EZFB__]2BXT$____C40!_%#_EQ`!``"+C03___^#Q!"%
MP`]%C?C^__^)C?C^___I9?S__^BP!P``BT7D92L%%````'7O@^P,C8>NHO__
M4&?H)/7__XUT)@!5B>575HU]X%.)^N@PU?__@<-`<0``@^PL98LU%````(EU
MY(NSA````&6+#@^V062)3=2(066-@[>A___H+^3__X7`=`R`.#&+3=0/A&\!
M``!GZ#GP__]EBPZ-@^>B__]J`VH!4%'_DTP```"#Q!"%P'0P@^P$C9/IHO__
M4HM0#(E%U/\R9?\V_Y-0````BT74BT`,@\00BP#V0`I`#X5%`0``C8/NHO__
M:@-J`5!E_S;_DTP```"#Q!"%P(E%U'0PB?J-@X6A___HHN/__XM-U(G"BT$,
MBP"%T@^$\````(/L!%)09?\V_Y-0````@\00@^P$C8/PHO__:@%09?\V_Y,@
M````C9,%H___@\0,4E!E_S;_DU````!EBP:)^L9`90"-@WRA___H0N/__X/$
M$(F#1`$``(G&A<!T0X/L"&C``0``5O^3&````(U0`8/$$(/Z`78)@_@1#X6=
M````BT7D92L%%`````^%L````(UE]%M>7UW#+HVT)@````"#[`S_LT@!``!G
MZ,'V__^)@T0!``")QH/$$(7`=9^+1>1E*P44````=7:#[`R-@Z2C__]0_Y/@
M````C;8`````@'@!``^$D/[__^F"_O__D(N32`$``(L2Z`/F___I#____XVV
M`````(/L"%!E_S;_D\@```"#Q!#IIO[__XM5Y&4K%10```!U%U!6BX-(`0``
M_S"-@\BC__]0_Y/@````Z&L%```NC;0F`````(UV`%6)Y5=6C57@4^@"T___
M@<,2;P``@^P<98LU%````(EUY(MU"(V#TZ'__^@1XO__A<!T&P^V$(32#Y3`
M@/HP#Y3""-!U"87V=`6`/@!U&HM%Y&4K!10```!U:HUE]%M>7UW#C;8`````
M@^P,5F?H;NS__XG'6%IJ+U?_DU@```"%P(U0`0]%^HD\)/^3"`$``(/$#(V3
MEJ+__VH$4E#_D_````"#Q!"%P'6DBT7D92L%%````'4.C67TB?!;7E]=Z=SB
M___HEP0``(VT)@````#H@@0```5+;@``58GE@^P4:F#_D,0```#'``$C16?'
M0`2)J\WOQT`(_MRZF,=`#'94,A#'0!#PX=+#QT`4`````,=`&`````#'0%P`
M````R<,NC;0F`````(VT)@````#HZP,``('!ZVT``%6)Y5=64X/L'(M]"(MU
M$(M7&(T$]0`````#1Q2-7QR)1Q2)\(/2`,'H'0'0B4<8BT=<A<`/A5,!``"#
M_C\/CKX```"-1L#![@:)?0B)WXU._\'F!HE%X(E-Y(M-#`'QBW4,B?.)SBZ-
MM"8`````C;0F`````(L#@\-`B0>+0\2)1P2+0\B)1PB+0\R)1PR+0]")1Q"+
M0]2)1Q2+0]B)1QB+0]R)1QR+0^")1R"+0^2)1R2+0^B)1RB+0^R)1RR+0_")
M1S"+0_2)1S2+0_B)1SB+0_R)1SR+10CH)]+__SGS=9.+1>"+30R)^XM5Y(M]
M"(G&@^#`C40!0,'B!HE%#"G6@_X$<E^+10R+`(E''(M%#(M$,/R)1#/\C4<@
MBU4,@^#\*<,IV@'S@^/\@_L$<B6)=1"#X_PQR8LT"HDT"(/!!#G9<O.+=1`N
MC;0F`````"Z-="8`B7=<C67T6UY?7<,NC70F`(7V=.R+10P/M@"(1QSWQ@(`
M``!TVXM%#`^W1##^9HE$,_[KS(UT)@"Z0````"G".?(/3]:#[`0!V%*)5>3_
M=0Q0_Y&@````BT=<BU7D`="#Q!")1UR#^$!UF8GX`54,*=;H.M'__^EJ_O__
M+HUT)@#H0@(```4+;```58GE5U93@^P<BUT,BW4(B47DBT,4BU,8B<?!Z`,/
MRHE5W(/@/P_/B7W@C7L<C5`!QD0#'("-!!>#^C@/CO4```"Y0````"G1=!LQ
MTO;!`0^%@0$``,8$$`#&1!`!`(/"`CG*<O")V.BZT/__C5<$QT,<`````#'`
M@^+\QT<T`````"G7C4\XB=?!Z0+SJXM%W(E#5(M%X(E#6(G8Z(70__^+`\'H
M&(@&BP/!Z!"(1@&+`XAF`HL#B$8##[9#!XA&!`^W0P:(1@6+0P2(9@:+0P2(
M1@</MD,+B$8(#[=#"HA&"8M#"(AF"HM#"(A&"P^V0P^(1@P/MT,.B$8-BT,,
MB&8.BT,,B$8/#[9#$XA&$`^W0Q*(1A&+0Q"(9A*+0Q"(1A.+1>2)70B#Q!Q;
M7E]=_Z!H````D+DX````*=&#^01R=(U0!,<``````(/B_,=$"/P`````*=`!
MR(/@_(/X!`^"*/___XG!OP0```"#X?R)3=B-2/_!Z0+'`@````"#X0$YQP^#
M!/___X7)=6#'!#H`````QT0Z!`````"+1=B#QP@YQW+GZ>+^__\NC;0F````
M`&:0A<D/A-#^___&``#VP0(/A,3^__\QTF:)5`C^Z;C^__^Z`0```,8``#G*
M#X)O_O__Z7K^__^-=@#'0@0`````BT78OP@````YQW*-Z8C^__^+#"3#BS0D
MPXL\),-FD&:0Z"(````%ZVD``%6)Y8/L"/^P)`$``/]U$/]U#/]U"/^01```
M`,G#BP0DPV:09I"0Z/+___\%NVD``%6)Y8/L"/^0S```````4X/L".B/S?__
M@<.?:0``@\0(6\,`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````P````$``@`E<R\E<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D
M97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O<V5L9B]E>&4`+W!R;V,O
M)6DO)7,`+@!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%
M4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!
M5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,
M7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!
M3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`,0!L<V5E:R!F86EL960`<F5A9"!F
M86EL960`3$1?3$E"4D%265]0051(`%-94U1%30`O=&UP`%1%35!$25(`5$U0
M`%5315(`55-%4DY!344`)3`R>`!P87(M`"5S)7,E<R5S`'!A<FP`+G!A<@!S
M:&]R="!R96%D`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E
M;7`M)74M)74E<P`8`'!E<FP`,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`V
M,P`M90`M+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O
M<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R
M>2!Y;W5R(&]P97)A=&EO;BD*``!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I
M<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D
M:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`````&5V86P@)V5X96,@
M+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R
M=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@
M*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S
M:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,
M15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?
M<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B
M(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I
M>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM
M>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[
M("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I
M>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A
M9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I
M.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P
M*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*
M?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP
M9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.
M?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA
M;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@
M9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H
M*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D[
M"G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@
M)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!
M5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P*
M*3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@
M/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F
M("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB
M<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I
M;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE
M.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y
M<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S
M<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)
M3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N
M86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P
M("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@
M("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE
M>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R
M+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;
M7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*
M;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D[
M"FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'
M24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H
M;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T
M(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D
M(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*
M;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA
M9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN
M9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!
M1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G
M:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T
M7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L
M(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@
M)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O
M=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B
M=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F
M<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ
M93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S
M970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(
M+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P
M.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U
M:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@
M("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F
M(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B
M=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO
M=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C
M<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q
M(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH
M/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@
M7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X
M="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F
M:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64[
M"B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M
M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]
M/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R
M97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T
M.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]
M($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I
M;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I
M;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D
M=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?
M0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@
M/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@
M=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I
M;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE
M;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP
M;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64[
M"F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@
M(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D
M=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!
M4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E
M<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K
M97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA
M;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE
M(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92![
M"F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M
M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE
M?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z
M:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M
M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@
M+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?
M87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I
M.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D55
M4T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S
M(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2![
M"FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A
M;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R
M:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E
M)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T
M($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`
M861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;
M04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I
M('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@
M>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF
M="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]
M("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*
M?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I
M9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,
M)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P
M96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*
M)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD
M(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ
M)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D
M7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O
M7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q
M=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@
M)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A
M<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N
M)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z
M.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E
M("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@
M;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T
M82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M
M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE
M9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q
M<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR
M96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@
M9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@[
M"GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H
M"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2
M*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#
M86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D[
M"G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A
M<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A
M<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F
M.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@
M86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P
M<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D
M:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF
M("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ
M7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L
M97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B
M=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R
M8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X
M<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM
M>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H
M87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N
M9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V
M<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@
M:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D
M*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D
M9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@
M;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI
M)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II
M9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@
M)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H
M)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE
M+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X
M="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M
M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D
M;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E
M<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*
M;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I
M;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY
M("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F
M:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D
M/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^
M("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N
M="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H
M+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL
M"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S
M,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N
M="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D
M960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D
M;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N
M9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R
M;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P
M87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*
M:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z
M.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D
M9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD
M:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L
M("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X](")<,"(@>"`H)&-A
M8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I
M;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F
M:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.
M)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D
M(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S
M=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I
M;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE
M+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z
M.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I
M;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A
M73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II
M<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI
M"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA
M;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*
M<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R
M;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF
M("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A
M="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB
M97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M
M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE
M;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@
M/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.
M5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M
M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO
M=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A
M9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q
M6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN
M72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT
M<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U
M-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL
M97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@
M=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER
M(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P
M(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B
M($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ
M0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z
M.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER
M92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S
M<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R
M97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A
M9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E
M('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER
M92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E
M<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE
M.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q
M=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I
M<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*
M979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T[
M"F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER
M92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE
M.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/
M.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T
M9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A
M<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA
M<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-
M4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE
M<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM
M>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P
M=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R
M.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M
M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W
M=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D
M14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H
M)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK
M9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM0
M05)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92![
M"F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S
M(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA
M9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%
M(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#
M2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G
M:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B
M*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C
M:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B
M8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER
M*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`]
M(#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM
M:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I
M<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R![
M"FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN
M86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE
M*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO
M<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C
M;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I
M;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I
M9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I
M(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*
M<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'
M3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R
M;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%2
M7U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^
M/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D
M<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%2
M7U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@
M/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E
M='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5]
M(BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R
M96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.
M5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@
M)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L
M:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O
M9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L
M:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D
M<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES
M>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD
M,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD
M97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@
M/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I
M;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D
M("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*
M8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?
M9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-
M17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%
M3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E
M('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%7
M3D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L
M971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,
M14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/
M0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II
M9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*
M?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@
M>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B([
M"GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#
M+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*
M87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*
M=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X[
M"G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*
M4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@
M;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R
M(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA
M;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K
M*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`
M.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)
M5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*
M,3L*7U]%3D1?7PH``$-!0TA%``!P97)L>'-I+F,````!&P,[&`$``"(```"P
M?___8`$``-!___^4!0``,(+__S0!``"0@___A`$``)"1__^T`0``8)+___0!
M``#PDO__(`(``*"4__]0`@```)7__W@"``#@E?__J`(``&"8___<`@``H)C_
M__P"``"`F?__+`,``)"9__]``P``\)O__W`#```PG/__F`,``+"=___8`P``
MX*'__P@$``!`HO__+`0``)"B__](!```8*3__W@$``"0I/__G`0``'"E___<
M!```(*W__R`%``!0K___5`4``""P___<!0``@+#___P%``!@LO__+`8``'"T
M__]<!@``=+3__W`&``!XM/__A`8``("T__^8!@``I[3__[@&``"PM/__S`8`
M`!0``````````7I2``%\"`$;#`0$B`$'"!`````<````](#__RP`````````
M%``````````!>E(``7P(`1L,!`2(`0``(````!P```!(?O__(``````."$8.
M#$H/"W0$>``_&CLJ,B0B+````$`````$@O__]PT```!!#@B%`D(-!4F'`X8$
M@P4#X@T*PT'&0<=!Q0P$!$$+/````'````#4C___PP````!!#@B%`D0-!4&'
M`U"&!(,%`FH*PT'&0<=!Q0P$!$4+<PK#0<9!QT'%#`0$00L``"@```"P````
M9)#__X(`````00X(A0)"#05!A@-/@P0"9PK#0<9!Q0P$!$$++````-P```#(
MD/__H@$```!!#@B%`D(-!4*'`X8$4H,%:0K#0<9!QT'%#`0$10L`)`````P!
M``!(DO__7P````!!#@B%`D(-!4*&`X,$`E?#0<9!Q0P$!"P````T`0``@)+_
M_]P`````00X(A0)"#050AP.&!(,%`GT*PT'&0<=!Q0P$!$$+`#````!D`0``
M,)/__W("````00X(A0)"#05!AP-%A@1/@P4#.P$*PT'&0<=!Q0P$!$H+```<
M````F`$``'R5__\X`````$L."(4"0@T%:L4,!`0``"P```"X`0``G)7__]H`
M````00X(A0)"#05:AP.&!(,%`K0*PT'&0<=!Q0P$!$$+`!````#H`0``3);_
M_Q``````````+````/P!``!(EO__5P(```!!#@B%`D(-!5.'`X8$@P4"?0K#
M0<9!QT'%#`0$2@L`)````"P"``!XF/__.P````!!#@B%`D(-!4&&`TR#!&/#
M0<9!Q0P$!#P```!4`@``D)C__W0!````00X(A0)"#050AP.&!(,%`M`*PT'&
M0<=!Q0P$!$H+60K#0<9!QT'%#`0$3`L````L````E`(``-"9__\O!````$P.
M"(4"0@T%0X<#A@2#!0/Q`PK#0<9!QT'%#`0$10L@````Q`(``-"=__]9````
M`$L."(4"0@T%`D(*Q0P$!$$+```8````Z`(```R>__]"`````$$."(4"0@T%
M08,#+`````0#``!`GO__S@$```!!#@B%`D(-!4.'`X8$@P4#5@$*PT'&0<=!
MQ0P$!$$+(````#0#``#@G___,`````!!#@B%`D(-!4&#`VO%PPP$!```/```
M`%@#``#LG___V0````!!#@B%`D(-!4&'`U"&!(,%`D0*PT'&0<=!Q0P$!$4+
M`FP*PT'&0<=!Q0P$!$4+`$````"8`P``C*#__ZP'````00X(A0)"#05!AP-3
MA@2#!0/"`@K#0<9!QT'%#`0$1`L#%@,*PT'&0<=!Q0P$!$<+````,````-P#
M``#XI___)0(```!!#@B%`D(-!4*'`X8$1H,%`VD!"L-!QD''0<4,!`1)"P``
M`#P````0!```]*G__\D`````00X(A0)"#05&AP.&!(,%`E4*PT'&0<=!Q0P$
M!$<+`E0*PT'&0<=!Q0P$!$4+``!$````4`0``#1Z__]6`@```$0,`0!)$`4"
M=0!!$`<"=7Q$$`8"=7@0`P)U=$P/`W5P!@-O`0K!#`$`0<-!QD''0<5##`0$
M00L<````F`0``#RJ__]1`````$L."(4"0@T%`D/%#`0$`"P```"X!```?*K_
M_]L!````3`X(A0)"#05&AP.&!(,%`U,!"L-!QD''0<4,!`1&"RP```#H!```
M+*S__Q`"````2PX(A0)"#05&AP.&!(,%`R,!"L-!QD''0<4,!`1'"Q`````8
M!0``#*[__P0`````````$````"P%``#\K?__!``````````0````0`4``.RM
M__\$`````````!P```!4!0``X*W__R<`````2PX(A0)"#059Q0P$!```$```
M`'0%``#GK?__!``````````8````B`4``-RM__\6`````$L."(4"0@T%````
M``````0````0`````0```$=.50``````!`````0`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````P",``'`C```!````!@,```$````1`P``'0```+<$```,
M`````"````T````X50``&0```+B]```;````!````!H```"\O0``'`````0`
M``#U_O]O-`(```4```!\"0``!@```'P#```*````V@0```L````0````%0``
M```````#````X+X```(````(````%````!$````7````V!$``!$```#(#P``
M$@```!`"```3````"````!X````(````^___;P$```C^__]O&`\``/___V\!
M````\/__;U8.```D````X!$``",````4````)0````0`````````````````
M``````````````````````````````````````````````````#`O0``````
M```````V(```````````````````````````````````````````````````
M````````````````D$T`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````$`@````````!,````I005(N<&T*`````.QB``!'0T,Z("A'3E4I
M(#$T+C(N,2`R,#(U,#(P-P``+G-H<W1R=&%B`"YN;W1E+F=N=2YB=6EL9"UI
M9``N;F]T92YG;G4N<')O<&5R='D`+FEN=&5R<``N9VYU+FAA<V@`+F1Y;G-Y
M;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y
M;@`N<F5L+G!L=``N<F5L<BYD>6X`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T
M80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N;F]T92Y!0DDM=&%G`"YI;FET
M7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N
M8V]M;65N=```````````````````````````````````````````````````
M````"P````<````"````U`$``-0!```D```````````````$`````````!X`
M```'`````@```/@!``#X`0``*```````````````!``````````Q`````0``
M``(````@`@``(`(``!,```````````````$`````````.0```/;__V\"````
M-`(``#0"``!(`0``!0`````````$````!````$,````+`````@```'P#``!\
M`P````8```8````!````!````!````!+`````P````(```!\"0``?`D``-H$
M``````````````$`````````4P```/___V\"````5@X``%8.``#`````!0``
M```````"`````@```&````#^__]O`@```!@/```8#P``L`````8````!````
M!`````````!O````"0````(```#(#P``R`\``!`"```%``````````0````(
M````>`````D```!"````V!$``-@1```(````!0```!<````$````"````($`
M```3`````@```.`1``#@$0``%```````````````!`````0```"+`````0``
M``8`````(````"```"````````````````0`````````?`````$````&````
M("```"`@```@```````````````0````!````)$````!````!@```$`@``!`
M(```]C0`````````````0`````````"7`````0````8````X50``.%4``!0`
M``````````````0`````````G0````$````"`````&````!@``!N0```````
M```````$`````````*4````!`````@```'"@``!PH```'`$`````````````
M!`````````"S`````0````(```",H0``C*$``-`%``````````````0`````
M````O0````<````"````7*<``%RG```@```````````````$`````````,L`
M```.`````P```+B]``"XK0``!```````````````!`````0```#7````#P``
M``,```"\O0``O*T```0```````````````0````$````XP````8````#````
MP+T``,"M```@`0``!@`````````$````"````.P````!`````P```."^``#@
MK@``(`$`````````````!`````0```#Q`````0````,`````P````+```!@`
M``````````````0`````````]P````@````#````&,```!BP```4````````
M```````$`````````/P````!````,``````````8L```&P``````````````
M`0````$````!`````P``````````````,[````4!``````````````$`````
#````
